summaryrefslogtreecommitdiff
path: root/src/user/app/tests/kernel/path.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/user/app/tests/kernel/path.c')
-rw-r--r--src/user/app/tests/kernel/path.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/user/app/tests/kernel/path.c b/src/user/app/tests/kernel/path.c
index e25154d..5fb3123 100644
--- a/src/user/app/tests/kernel/path.c
+++ b/src/user/app/tests/kernel/path.c
@@ -1,6 +1,7 @@
#include "../tests.h"
#include <camellia/path.h>
#include <string.h>
+#include <user/lib/compat.h>
#include <user/lib/fs/misc.h>
static void test_path_simplify(void) {
@@ -66,9 +67,9 @@ static void mount_resolve_drv(const char *path) {
if (fork2_n_mount(path)) return;
struct fs_wait_response res;
- while (!_syscall_fs_wait(NULL, 0, &res)) {
- // TODO does the first argument of _syscall_fs_respond need to be non-const?
- _syscall_fs_respond((void*)path, strlen(path), 0);
+ while (!c0_fs_wait(NULL, 0, &res)) {
+ // TODO does the first argument of c0_fs_respond need to be non-const?
+ c0_fs_respond((void*)path, strlen(path), 0);
}
exit(1);
}